@@ -2,6 +2,7 @@
 Command line module
 """
 import time
+from typing import Optional
 
 import click
 from click import Choice, Path
@@ -36,9 +37,19 @@ from face_group.api import process_images
     type=Choice(["hog", "cnn"]),
     help="Type of backend for computing features.",
 )
-def group_faces(input_dir: str, output_dir: str, verbose: bool, model: str) -> None:
+@click.option(
+    "-c",
+    "--cpus",
+    "cpus",
+    default=1,
+    type=int,
+    help='Number of CPU cores to use in parallel (can speed up processing lots of '
+         'images). -1 means "use all in system".',
+)
+def group_faces(input_dir: str, output_dir: str, verbose: bool, model: str, cpus: int) \
+        -> None:
     """It groups the faces of similar people"""
 
     start = time.time()
-    process_images(input_dir, output_dir, verbose, model)
+    process_images(input_dir, output_dir, verbose, model, cpus)
     click.echo(f"Done in {time.time() - start}s")
